@@ -1,3 +1,24 @@
+/*
+qgvdial is a cross platform Google Voice Dialer
+Copyright (C) 2010  Yuvraaj Kelkar
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+
+Contact: yuvraaj@gmail.com
+*/
+
 #include "SkypeObserver.h"
 #include "Singletons.h"
 
@@ -17,6 +38,7 @@ SkypeObserver::initClient ()
 {
     if (NULL != skypeClient)
     {
+        qDebug ("SkypeObserver: Skype client is already running.");
         return;
     }
 
@@ -24,7 +46,7 @@ SkypeObserver::initClient ()
     skypeClient = skypeFactory.ensureSkypeClient (SKYPE_CLIENT_NAME);
     if (NULL == skypeClient)
     {
-        qWarning ("Failed to create skype client");
+        qWarning ("SkypeObserver: Failed to create skype client");
         return;
     }
 
@@ -37,7 +59,7 @@ SkypeObserver::initClient ()
                                           this, SLOT (onInitSkype (bool, const QVariantList &)));
     if (!bret)
     {
-        qWarning ("Failed to initiate skype client init!");
+        qWarning ("SkypeObserver: Failed to initiate skype client init!");
         skypeFactory.deleteClient (SKYPE_CLIENT_NAME);
         skypeClient = NULL;
     }
@@ -48,7 +70,7 @@ SkypeObserver::onInitSkype (bool bSuccess, const QVariantList & /*params*/)
 {
     if (!bSuccess)
     {
-        qWarning ("Failed to init skype. Deleting");
+        qWarning ("SkypeObserver: Failed to init skype. Deleting");
 
         SkypeClientFactory &skypeFactory =
         Singletons::getRef().getSkypeFactory ();
@@ -58,7 +80,7 @@ SkypeObserver::onInitSkype (bool bSuccess, const QVariantList & /*params*/)
     }
     else
     {
-        qDebug ("Skype initialized");
+        qDebug ("SkypeObserver: Skype initialized");
 
         QObject::connect (
             skypeClient, SIGNAL (callStatusChanged   (uint, const QString &)),
@@ -71,11 +93,13 @@ SkypeObserver::startMonitoring (const QString &strC)
 {
     initClient ();
     strContact = strC;
+    qDebug() << "SkypeObserver: start monitoring for" << strContact;
 }//SkypeObserver::startMonitoring
 
 void
 SkypeObserver::stopMonitoring ()
 {
+    qDebug() << "SkypeObserver: stop monitoring for" << strContact;
     strContact.clear ();
 }//SkypeObserver::stopMonitoring
 
@@ -86,7 +110,7 @@ SkypeObserver::onCallStatusChanged (uint callId, const QString &strStatus)
     {
         if (NULL == skypeClient)
         {
-            qWarning ("WTF?? skypeClient == NULL");
+            qWarning ("SkypeObserver: WTF?? skypeClient == NULL");
             break;
         }
 
@@ -100,7 +124,7 @@ SkypeObserver::onCallStatusChanged (uint callId, const QString &strStatus)
                     (strText.contains ("FINISHED")))
                 {
                     arrCalls.remove (arrCalls.indexOf (callId));
-                    qDebug () << QString("Remove call id=%1").arg(callId);
+                    qDebug () << "SkypeObserver: Remove call id=" << callId;
                 }
             }
 
@@ -108,7 +132,8 @@ SkypeObserver::onCallStatusChanged (uint callId, const QString &strStatus)
         }
 
         arrCalls += callId;
-        qDebug () << QString("Add call id=%1. Begin get info").arg(callId);
+        qDebug () << "SkypeObserver: Added call id=" << callId
+                  << ". Begin get info";
 
         // Invoke get call info
         QVariantList l;
@@ -117,7 +142,7 @@ SkypeObserver::onCallStatusChanged (uint callId, const QString &strStatus)
                     SLOT (onCallInfoDone(bool, const QVariantList &)));
         if (!rv)
         {
-            qWarning ("Failed to get call info");
+            qWarning ("SkypeObserver: Failed to get call info");
         }
     } while (0); // End cleanup block (not a loop)
 }//SkypeObserver::onCallStatusChanged
@@ -129,41 +154,41 @@ SkypeObserver::onCallInfoDone (bool bOk, const QVariantList &params)
     {
         if (!bOk)
         {
-            qWarning ("Failed to add call");
+            qWarning ("SkypeObserver: Failed to add call");
             break;
         }
 
         Skype_CallInfo callInfo;
         if (!params[1].canConvert<Skype_CallInfo> ())
         {
-            qWarning ("QVariant cannot convert call info");
+            qWarning ("SkypeObserver: QVariant cannot convert call info");
             break;
         }
 
         callInfo = params[1].value<Skype_CallInfo> ();
-        qDebug () << QString("Get info for %1 done.")
+        qDebug () << QString("SkypeObserver: Get info for %1 done.")
                           .arg(params[0].toUInt ());
         if (!callInfo.bIncoming_valid ||
             !callInfo.bIncoming ||
             !callInfo.bPartnerHandle_valid)
         {
-            qDebug ("Not a call of interest.");
+            qDebug ("SkypeObserver: Not a call of interest.");
             break;
         }
 
         if (0 == strContact.size ())
         {
-            qDebug ("We have not been asked to observe");
+            qDebug ("SkypeObserver: We have not been asked to observe");
             break;
         }
 
         if (!callInfo.strPartnerHandle.contains(strContact))
         {
-            qDebug ("Incoming call not from our number");
+            qDebug ("SkypeObserver: Incoming call not from our number");
             break;
         }
 
-        qDebug ("Call is of interest to us!");
+        qDebug ("SkypeObserver: Call is of interest to us!");
         emit callStarted ();
     } while (0); // End cleanup block (not a loop)
 }//SkypeObserver::onCallInfoDone
